@@ -1,21 +1,8 @@
 /*
-  Copyright (c) 2002 Cornelius Schumacher <schumacher@kde.org>
-  Copyright (c) 2005 Rafal Rzepecki <divide@users.sourceforge.net>
+  SPDX-FileCopyrightText: 2002 Cornelius Schumacher <schumacher@kde.org>
+  SPDX-FileCopyrightText: 2005 Rafal Rzepecki <divide@users.sourceforge.net>
 
-  This library is free software; you can redistribute it and/or
-  modify it under the terms of the GNU Library General Public
-  License as published by the Free Software Foundation; either
-  version 2 of the License, or (at your option) any later version.
-
-  This library is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-  Library General Public License for more details.
-
-  You should have received a copy of the GNU Library General Public License
-  along with this library; see the file COPYING.LIB.  If not, write to
-  the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-  Boston, MA 02110-1301, USA.
+  SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "categoryconfig.h"
@@ -36,19 +23,19 @@ static QStringList categoryDefaults()
       << i18nc("incidence category: phone call", "Phone Call")
       << i18nc("incidence category", "Education")
       << i18nc("incidence category: "
-               "official or unofficial observance of "
-               "religious/national/cultural/other significance, "
-               "often accompanied by celebrations or festivities", "Holiday")
+             "official or unofficial observance of "
+             "religious/national/cultural/other significance, "
+             "often accompanied by celebrations or festivities", "Holiday")
       << i18nc("incidence category: "
-               "a lengthy time away from work or school, a trip abroad, "
-               "or simply a pleasure trip away from home", "Vacation")
+             "a lengthy time away from work or school, a trip abroad, "
+             "or simply a pleasure trip away from home", "Vacation")
       << i18nc("incidence category: "
-               "examples: anniversary of historical or personal event; "
-               "big date; remembrance, etc", "Special Occasion")
+             "examples: anniversary of historical or personal event; "
+             "big date; remembrance, etc", "Special Occasion")
       << i18nc("incidence category", "Personal")
       << i18nc("incidence category: "
-               "typically associated with leaving home for business, "
-               "and not pleasure", "Travel")
+             "typically associated with leaving home for business, "
+             "and not pleasure", "Travel")
       << i18nc("incidence category", "Miscellaneous")
       << i18nc("incidence category", "Birthday");
     return l;
@@ -63,7 +50,7 @@ public:
     }
 
     QColor mDefaultCategoryColor;
-    KCoreConfigSkeleton *config;
+    KCoreConfigSkeleton *const config;
 };
 
 QHash<QString, QColor> CategoryConfig::readColors() const
@@ -94,7 +81,8 @@ void CategoryConfig::setColors(const QHash<QString, QColor> &colors)
 }
 
 CategoryConfig::CategoryConfig(KCoreConfigSkeleton *cfg, QObject *parent)
-    : QObject(parent), d(new Private(cfg))
+    : QObject(parent)
+    , d(new Private(cfg))
 {
 }
 
@@ -123,4 +111,3 @@ void CategoryConfig::setCustomCategories(const QStringList &categories)
 }
 
 const QString CategoryConfig::categorySeparator(QLatin1Char(':'));
-
