@@ -1,21 +1,8 @@
 /*
-  Copyright (C) 2010 Casey Link <unnamedrambler@gmail.com>
-  Copyright (C) 2009-2010 Klaralvdalens Datakonsult AB, a KDAB Group company <info@kdab.net>
+  SPDX-FileCopyrightText: 2010 Casey Link <unnamedrambler@gmail.com>
+  SPDX-FileCopyrightText: 2009-2010 Klaralvdalens Datakonsult AB, a KDAB Group company <info@kdab.net>
 
-  This library is free software; you can redistribute it and/or modify it
-  under the terms of the GNU Library General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or (at your
-  option) any later version.
-
-  This library is distributed in the hope that it will be useful, but WITHOUT
-  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-  FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
-  License for more details.
-
-  You should have received a copy of the GNU Library General Public License
-  along with this library; see the file COPYING.LIB.  If not, write to the
-  Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
-  02110-1301, USA.
+  SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #ifndef FBMODEL_FREEBUSYITEMMODEL_H
@@ -30,9 +17,7 @@
 
 class ItemPrivateData;
 
-namespace CalendarSupport
-{
-
+namespace CalendarSupport {
 /**
  * The FreeBusyItemModel is a 2-level tree structure.
  *
@@ -52,25 +37,23 @@ public:
     };
 
     explicit FreeBusyItemModel(QObject *parent = nullptr);
-    virtual ~FreeBusyItemModel();
+    ~FreeBusyItemModel() override;
 
     QVariant data(const QModelIndex &index, int role = Qt::DisplayRole) const override;
     int rowCount(const QModelIndex &parent = QModelIndex()) const override;
     int columnCount(const QModelIndex &parent = QModelIndex()) const override;
-    QModelIndex index(int row, int column = 0,
-                      const QModelIndex &parent = QModelIndex()) const override;
+    QModelIndex index(int row, int column = 0, const QModelIndex &parent = QModelIndex()) const override;
     QModelIndex parent(const QModelIndex &child) const override;
-    QVariant headerData(int section, Qt::Orientation orientation,
-                        int role = Qt::DisplayRole) const override;
+    QVariant headerData(int section, Qt::Orientation orientation, int role = Qt::DisplayRole) const override;
 
     void addItem(const FreeBusyItem::Ptr &freebusy);
 
     void clear();
-    void removeAttendee(const KCalCore::Attendee::Ptr &attendee);
+    void removeAttendee(const KCalendarCore::Attendee &attendee);
     void removeItem(const FreeBusyItem::Ptr &freebusy);
     void removeRow(int row);
 
-    bool containsAttendee(const KCalCore::Attendee::Ptr &attendee);
+    Q_REQUIRED_RESULT bool containsAttendee(const KCalendarCore::Attendee &attendee);
 
     /**
      * Queues a reload of free/busy data.
@@ -90,24 +73,19 @@ public:
     void reload();
 
 public Q_SLOTS:
-    void slotInsertFreeBusy(const KCalCore::FreeBusy::Ptr &fb, const QString &email);
+    void slotInsertFreeBusy(const KCalendarCore::FreeBusy::Ptr &fb, const QString &email);
 
 protected:
     void timerEvent(QTimerEvent *) override;
 
-private Q_SLOTS:
-    // Force the download of FB information
-    void manualReload();
+private:
     // Only download FB if the auto-download option is set in config
     void autoReload();
 
-private:
-    void setFreeBusyPeriods(const QModelIndex &parent,
-                            const KCalCore::FreeBusyPeriod::List &list);
+    void setFreeBusyPeriods(const QModelIndex &parent, const KCalendarCore::FreeBusyPeriod::List &list);
     void updateFreeBusyData(const FreeBusyItem::Ptr &);
 
     FreeBusyItemModelPrivate *const d;
 };
-
 }
 #endif
