@@ -1,31 +1,18 @@
 /*
-  Copyright (C) 2010 Casey Link <unnamedrambler@gmail.com>
-  Copyright (C) 2009-2010 Klaralvdalens Datakonsult AB, a KDAB Group company <info@kdab.net>
+  SPDX-FileCopyrightText: 2010 Casey Link <unnamedrambler@gmail.com>
+  SPDX-FileCopyrightText: 2009-2010 Klaralvdalens Datakonsult AB, a KDAB Group company <info@kdab.net>
 
-  This library is free software; you can redistribute it and/or modify it
-  under the terms of the GNU Library General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or (at your
-  option) any later version.
-
-  This library is distributed in the hope that it will be useful, but WITHOUT
-  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-  FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
-  License for more details.
-
-  You should have received a copy of the GNU Library General Public License
-  along with this library; see the file COPYING.LIB.  If not, write to the
-  Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
-  02110-1301, USA.
+  SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "freeperiodmodel.h"
 
-#include <KCalCore/Period>
 
 #include <KLocalizedString>
 #include <KFormat>
-#include <KSystemTimeZones>
 
+#include <QDateTime>
+#include <QTimeZone>
 #include <QLocale>
 #include <QSet>
 
@@ -94,7 +81,7 @@ QVariant FreePeriodModel::headerData(int section, Qt::Orientation orientation, i
     return QAbstractItemModel::headerData(section, orientation, role);
 }
 
-void FreePeriodModel::slotNewFreePeriods(const KCalCore::Period::List &freePeriods)
+void FreePeriodModel::slotNewFreePeriods(const KCalendarCore::Period::List &freePeriods)
 {
     beginResetModel();
     mPeriodList.clear();
@@ -103,23 +90,23 @@ void FreePeriodModel::slotNewFreePeriods(const KCalCore::Period::List &freePerio
     endResetModel();
 }
 
-KCalCore::Period::List FreePeriodModel::splitPeriodsByDay(
-    const KCalCore::Period::List &freePeriods)
+KCalendarCore::Period::List FreePeriodModel::splitPeriodsByDay(
+    const KCalendarCore::Period::List &freePeriods)
 {
-    KCalCore::Period::List splitList;
-    for (const KCalCore::Period &period : freePeriods) {
-        if (period.start().date() == period.end().date())  {
+    KCalendarCore::Period::List splitList;
+    for (const KCalendarCore::Period &period : freePeriods) {
+        if (period.start().date() == period.end().date()) {
             splitList << period; // period occurs on the same day
             continue;
         }
 
         const int validPeriodSecs = 300; // 5 minutes
-        KCalCore::Period tmpPeriod = period;
+        KCalendarCore::Period tmpPeriod = period;
         while (tmpPeriod.start().date() != tmpPeriod.end().date()) {
-            const KDateTime midnight(tmpPeriod.start().date(), QTime(23, 59, 59, 999),
-                                     tmpPeriod.start().timeSpec());
-            KCalCore::Period firstPeriod(tmpPeriod.start(), midnight);
-            KCalCore::Period secondPeriod(midnight.addMSecs(1), tmpPeriod.end());
+            const QDateTime midnight(tmpPeriod.start().date(), QTime(23, 59, 59, 999),
+                                     tmpPeriod.start().timeZone());
+            KCalendarCore::Period firstPeriod(tmpPeriod.start(), midnight);
+            KCalendarCore::Period secondPeriod(midnight.addMSecs(1), tmpPeriod.end());
             if (firstPeriod.duration().asSeconds() >= validPeriodSecs) {
                 splitList << firstPeriod;
             }
@@ -131,16 +118,14 @@ KCalCore::Period::List FreePeriodModel::splitPeriodsByDay(
     }
 
     // Perform some jiggery pokery to remove duplicates
-
-    QList<KCalCore::Period> tmpList = splitList.toList();
-    const QSet<KCalCore::Period> set = tmpList.toSet();
-    tmpList = QList<KCalCore::Period>::fromSet(set);
-    return KCalCore::Period::List::fromList(tmpList);
+    std::sort(splitList.begin(), splitList.end());
+    splitList.erase(std::unique(splitList.begin(), splitList.end()), splitList.end());
+    return splitList;
 }
 
 QString FreePeriodModel::day(int index) const
 {
-    KCalCore::Period period = mPeriodList.at(index);
+    KCalendarCore::Period period = mPeriodList.at(index);
     const QDate startDate = period.start().date();
     return ki18nc("@label Day of the week name, example: Monday,", "%1,").
            subs(QLocale::system().dayName(startDate.dayOfWeek(), QLocale::LongFormat)).toString();
@@ -148,10 +133,11 @@ QString FreePeriodModel::day(int index) const
 
 QString FreePeriodModel::date(int index) const
 {
-    KCalCore::Period period = mPeriodList.at(index);
+    KCalendarCore::Period period = mPeriodList.at(index);
 
     const QDate startDate = period.start().date();
-    const QString startTime = QLocale::system().toString(period.start().time(), QLocale::ShortFormat);
+    const QString startTime
+        = QLocale::system().toString(period.start().time(), QLocale::ShortFormat);
     const QString endTime = QLocale::system().toString(period.end().time(), QLocale::ShortFormat);
     const QString longMonthName = QLocale::system().monthName(startDate.month());
     return ki18nc("@label A time period duration. It is preceded/followed (based on the "
@@ -166,12 +152,13 @@ QString FreePeriodModel::date(int index) const
 
 QString FreePeriodModel::stringify(int index) const
 {
-    KCalCore::Period period = mPeriodList.at(index);
+    KCalendarCore::Period period = mPeriodList.at(index);
 
     const QDate startDate = period.start().date();
     const QString startTime = QLocale().toString(period.start().time(), QLocale::ShortFormat);
     const QString endTime = QLocale().toString(period.end().time(), QLocale::ShortFormat);
-    const QString longMonthName = QLocale::system().monthName(startDate.month(), QLocale::LongFormat);
+    const QString longMonthName
+        = QLocale::system().monthName(startDate.month(), QLocale::LongFormat);
     const QString dayofWeek = QLocale::system().dayName(startDate.dayOfWeek(), QLocale::LongFormat);
 
     // TODO i18n, ping chusslove
@@ -187,21 +174,22 @@ QString FreePeriodModel::stringify(int index) const
 
 QString FreePeriodModel::tooltipify(int index) const
 {
-    KDateTime::Spec timeSpec = KSystemTimeZones::local();
-    KCalCore::Period period = mPeriodList.at(index);
+    KCalendarCore::Period period = mPeriodList.at(index);
     unsigned long duration = period.duration().asSeconds() * 1000; // we want milliseconds
     QString toolTip = QStringLiteral("<qt>");
     toolTip += QLatin1String("<b>") + i18nc("@info:tooltip", "Free Period") + QLatin1String("</b>");
     toolTip += QLatin1String("<hr>");
-    toolTip += QLatin1String("<i>") + i18nc("@info:tooltip period start time", "Start:") + QLatin1String("</i>&nbsp;");
-    toolTip += QLocale::system().toString(period.start().toTimeSpec(timeSpec).dateTime(), QLocale::ShortFormat);
+    toolTip += QLatin1String("<i>")
+               + i18nc("@info:tooltip period start time", "Start:") + QLatin1String("</i>&nbsp;");
+    toolTip += QLocale().toString(period.start().toLocalTime(), QLocale::ShortFormat);
     toolTip += QLatin1String("<br>");
-    toolTip += QLatin1String("<i>") + i18nc("@info:tooltip period end time", "End:") + QLatin1String("</i>&nbsp;");
-    toolTip += QLocale::system().toString(period.end().toTimeSpec(timeSpec).dateTime(), QLocale::ShortFormat);
+    toolTip += QLatin1String("<i>")
+               + i18nc("@info:tooltip period end time", "End:") + QLatin1String("</i>&nbsp;");
+    toolTip += QLocale().toString(period.end().toLocalTime(), QLocale::ShortFormat);
     toolTip += QLatin1String("<br>");
-    toolTip += QLatin1String("<i>") + i18nc("@info:tooltip period duration", "Duration:") + QLatin1String("</i>&nbsp;");
+    toolTip += QLatin1String("<i>")
+               + i18nc("@info:tooltip period duration", "Duration:") + QLatin1String("</i>&nbsp;");
     toolTip += KFormat().formatSpelloutDuration(duration);
     toolTip += QLatin1String("</qt>");
     return toolTip;
 }
-
