@@ -1,21 +1,8 @@
 /*
-  Copyright (c) 2010 Klarälvdalens Datakonsult AB, a KDAB Group company <info@kdab.com>
+  SPDX-FileCopyrightText: 2010 Klarälvdalens Datakonsult AB, a KDAB Group company <info@kdab.com>
     Author: Stephen Kelly <stephen@kdab.com>
 
-  This library is free software; you can redistribute it and/or modify it
-  under the terms of the GNU Library General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or (at your
-  option) any later version.
-
-  This library is distributed in the hope that it will be useful, but WITHOUT
-  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-  FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
-  License for more details.
-
-  You should have received a copy of the GNU Library General Public License
-  along with this library; see the file COPYING.LIB.  If not, write to the
-  Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
-  02110-1301, USA.
+  SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "incidenceattachmentmodel.h"
@@ -35,7 +22,6 @@ class IncidenceAttachmentModelPrivate
         : q_ptr(qq)
         , m_modelIndex(modelIndex)
         , m_item(item)
-        , m_monitor(nullptr)
     {
         if (modelIndex.isValid()) {
             QObject::connect(modelIndex.model(), SIGNAL(dataChanged(QModelIndex,QModelIndex)),
@@ -147,7 +133,7 @@ void IncidenceAttachmentModel::setItem(const Akonadi::Item &item)
 {
     Q_D(IncidenceAttachmentModel);
     if (!item.hasPayload<KCalendarCore::Incidence::Ptr>()) {
-        ItemFetchJob *job = new ItemFetchJob(item);
+        auto *job = new ItemFetchJob(item);
         job->fetchScope().fetchFullPayload(true);
         connect(job, SIGNAL(itemsReceived(Akonadi::Item::List)),
                 SLOT(itemFetched(Akonadi::Item::List)));
