@@ -1,23 +1,7 @@
 /*
-  Copyright (C) 2004 Reinhold Kainhofer <reinhold@kainhofer.com>
+  SPDX-FileCopyrightText: 2004 Reinhold Kainhofer <reinhold@kainhofer.com>
 
-  This program is free software; you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
-
-  This program is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-  GNU General Public License for more details.
-
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
-
-  As a special exception, permission is given to link this program
-  with any edition of Qt, and distribute the resulting executable,
-  without including the source code for Qt in the source distribution.
+  SPDX-License-Identifier: GPL-2.0-or-later WITH Qt-Commercial-exception-1.0
 */
 
 #include "journalprint.h"
@@ -38,7 +22,7 @@ QWidget *CalPrintJournal::createConfigWidget(QWidget *w)
 
 void CalPrintJournal::readSettingsWidget()
 {
-    CalPrintJournalConfig *cfg
+    auto *cfg
         = dynamic_cast<CalPrintJournalConfig *>((QWidget *)mConfigWidget);
     if (cfg) {
         mFromDate = cfg->mFromDate->date();
@@ -49,7 +33,7 @@ void CalPrintJournal::readSettingsWidget()
 
 void CalPrintJournal::setSettingsWidget()
 {
-    CalPrintJournalConfig *cfg
+    auto *cfg
         = dynamic_cast<CalPrintJournalConfig *>((QWidget *)mConfigWidget);
     if (cfg) {
         cfg->mFromDate->setDate(mFromDate);
@@ -94,7 +78,7 @@ void CalPrintJournal::saveConfig()
 void CalPrintJournal::setDateRange(const QDate &from, const QDate &to)
 {
     CalPrintPluginBase::setDateRange(from, to);
-    CalPrintJournalConfig *cfg
+    auto *cfg
         = dynamic_cast<CalPrintJournalConfig *>((QWidget *)mConfigWidget);
     if (cfg) {
         cfg->mFromDate->setDate(from);
